==> docfbe_2_2_33_59.zip: docfbe_2_2_33_59/source/TCFbESimilarityComputationAlgorithm.h <==
/*
    TCFbESimilarityComputationAlgorithm.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbESimilarityComputationAlgorithmH
#define TCFbESimilarityComputationAlgorithmH
//---------------------------------------------------------------------------
#include <Classes.hpp>

class TCFbEDataSet;
#include "TCFbEDataSet.h"
//---------------------------------------------------------------------------
class TCFbESimilarityComputationAlgorithm : public TPersistent
{
public:
    virtual __fastcall TCFbESimilarityComputationAlgorithm(void);    // RXgN^
    __fastcall ~TCFbESimilarityComputationAlgorithm();    // fXgN^

    virtual void __fastcall SetDataSet(TCFbEDataSet* DataSet) { this->DataSet = DataSet; }    // f[^Zbgݒ肷iTCFbEDataSet gɂĎs
    virtual double __fastcall ComputeSimilarity(int TargetRowIndex, int ComparedRowIndex) = 0;    // TargetRowIndex  AnotherRowIndex ̗ގxvZ

protected:
    TCFbEDataSet* DataSet;

private:

};
//---------------------------------------------------------------------------
#endif

==> docfbe_2_2_34_61.zip: docfbe_2_2_34_61/source/TCFbESimilarityComputationAlgorithm.h <==
/*
    TCFbESimilarityComputationAlgorithm.h    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#ifndef TCFbESimilarityComputationAlgorithmH
#define TCFbESimilarityComputationAlgorithmH
//---------------------------------------------------------------------------
#include <Classes.hpp>

class TCFbEDataSet;
#include "TCFbEDataSet.h"
//---------------------------------------------------------------------------
class TCFbESimilarityComputationAlgorithm : public TPersistent
{
public:
    virtual __fastcall TCFbESimilarityComputationAlgorithm(void);    // RXgN^
    __fastcall ~TCFbESimilarityComputationAlgorithm();    // fXgN^

    // TargetRowIndex  AnotherRowIndex ̗ގxvZ
    virtual double __fastcall ComputeSimilarity(TCFbETable* SimilarityComputationTable, int TargetRowIndex, int ComparedRowIndex) = 0;

protected:

    TCFbETable* SimilarityComputationTable;

private:

};
//---------------------------------------------------------------------------
#endif
